<?php
/**
* Create a Flare glossary (.flglo) file of
* links to glossary topics from an HTML
* <dl>.
* © 2017 Moneris Solutions Corporation, CC-BY-NC -SA 4.0
* @param string $argv[1] The HTML glossary file
*/
//get glossary file
$source = $argv[1];
$filename = "myglossary.flglo";
$d = new DOMDocument();
$d->load($source);
$xp = new DOMXPath($d);
$ns = $d->documentElement->namespaceURI;
if($ns) {
  $xp->registerNamespace("ns", $ns);
  //find all dt
$nodelist = $xp->query('//ns:dt');
} else {
  $nodelist = $xp->query('//dt');
}
if(! $nodelist->item(0)) {
  exit("Element not found.");
}
$flare_doc = makeRoot();
//loop through nodes
foreach($nodelist as $node){
  createGlossaryEntry($node, $flare_doc);
}
$flare_doc->save($filename);
//end main
/**
* Create a DOMDocument with a root node
* @return DOMDocument
*/
function makeRoot(){
  $flare_doc = new DOMDocument();
  //create document with CatapultToc root
  $root = $flare_doc->createElement('CatapultGlossary');
  $flare_doc->appendChild($root);
  return $flare_doc;
}
/**
* Create a glossary entry
* @param DOMNode $node The <dt> node holding the term
* @param DOMDocument $flare_doc The new document
*/
function createGlossaryEntry($node, $flare_doc){
  //node is a glossentry
  $glossentry = $flare_doc->createElement('GlossaryEntry');
  //always create popup
  $glossentry->setAttribute("TermClass", "Popup" );
  //create Terms
  $terms = $flare_doc->createElement('Terms');
  //get text from node
  $value = trim($node->textContent);
  $term = $flare_doc->createElement('Term', $value);
  $terms->appendChild($term);
  $glossentry->appendChild($terms);
  //create definition
  $def = $flare_doc->createElement('Definition');
  //clean file name
  $pattern = "([\/\s\-_~,;:\[\]\(\).])";
  $value = preg_replace($pattern, "", $value);
  $current_dir = basename(getcwd());
  $url = "/Content/$current_dir/gloss_entries/" . $value . ".html";
  $def->setAttribute("Link", $url );
  $glossentry->appendChild($def);
  $flare_doc->documentElement->appendChild($glossentry);
}
?>
