<?php
/**
* Convert DocBook generated index file,
* works for <primary> only.
* index.links.to.section must be off
* @param string $argv[1] The index file
*/
$source = $argv[1]; 
$doc = new DOMDocument();
$doc->load($source);
$arr = createArray($doc);
createIndexEntry($arr);
/**
* Create key->value array of link and index term
* @param DOMDocument $doc The index file
* @return Array
*/
function createArray($doc) { 
  $a = Array();
  $xpath = new DOMXPath($doc);
  $ns = $doc->documentElement->namespaceURI;
  if($ns) {
    $xpath->registerNamespace("ns", $ns);
    $elements = $xpath->query("//ns:dt/ns:a");
  } else {
    $elements = $xpath->query("//dt/a");
  }
  $node = $elements->item(0);
  if(! $node) {
    exit("Anchors not found.");
  }
  foreach ($elements as $e){
    $val = trim($e->parentNode->firstChild->nodeValue, ", ");
    $a[$e->getAttribute("href")] = $val;
  }
  return $a;
}
/**
* Create a MadCap:keyword for each item in an index file.
* @param Array $arr key/value array of anchor and term
*/
function createIndexEntry($arr){
  foreach ($arr as $i => $value) { 
    //get file name from $i
    $file = parse_url($i, PHP_URL_PATH); 
    //find anchor
    $anchor = parse_url($i, PHP_URL_FRAGMENT);
    $doc = new DOMDocument();
    $doc->load($file);
    $xpath = new DOMXPath($doc);
    $ns = $doc->documentElement->namespaceURI;
    if($ns) {
      $xpath->registerNamespace("ns", $ns);
      $elements = $xpath->query("//ns:a[@id='$anchor']");
    } else {
      $elements = $xpath->query("//a[@id='$anchor']");
    }
    //there should only be one anchor
    $node = $elements->item(0);
    if(! $node) {
      echo "Anchor not found!";
      continue;
    }
    //replaceChild
    $key = $doc->createElement('MadCap:keyword');
    $key->setAttribute("term", $value);
    $parent = $node->parentNode;
    $parent->replaceChild($key, $node); 
    //save file
    $doc->save($file);
  }
}
?>