<?php
/**
* Compare titles to header tags.
* Identify pages where they differ.
* Search utility in Flare shows the
* value of the header so this mismatch can be 
* misleading.
* © 2017 Moneris Solutions Corporation, CC-BY-NC -SA 4.0
*/
error_reporting(E_ERROR);
$dest = "_titles.html"; 
//create array of headers, key is file name
$headers = getHeaders();
$contents = findDifferences($headers);
file_put_contents($dest, $contents);
exec("firefox $dest"); 
//end main
/**
* Create an array of headers
* @return Array 
*/
function getHeaders(){
  $headers = Array();
  foreach (glob("./*.{xhtml,html,htm}", GLOB_BRACE) as $file){    
    $file = basename($file);
    $query = "//*[self::ns:h1 or self::ns:h2 or self::ns:h3]"; 
    $nodelist = getNodes($file, $query);
    //get the first item
    if ($nodelist->item(0)){  
      //$file as key, header as value
      $headers[$file] =  $nodelist->item(0)->nodeValue;
    } else {
      $headers[$file] = "";
    }
  }
  return $headers;
}
/**
* Compare the array of headers to the title.
* @param Array $headers The array of headers
* @return $contents The HTML page
*/
function findDifferences($headers){
  $s = " style=\"font-family: Courier;\"";
  $contents = "<html><body $s><h1>Title &amp; Header Differences</h1>";
  //find all HTML files in the current directory
  foreach (glob("./*.{xhtml,html,htm}", GLOB_BRACE) as $file){     
    $file = basename($file);
    $query = "//ns:title";
    $elements = getNodes($file, $query);
    if($elements->item(0)){ //only concerned where there's a title  
      //strip out whitespace
      $title = preg_replace('/\s+/', '', $elements->item(0)->nodeValue); 
      $header = preg_replace('/\s+/', '', $headers[$file]);     
      if ($title != $header){ 
        $message = "Mismatch in " . $file;
        $length = strlen($message);    
        $contents .= "\n<br /><p>" . $message . "</p>\n";
        $contents .= "<p>" . str_repeat("-" , $length) . "</p>\n";          
        $contents .= "<p> &nbsp;title: " . $elements->item(0)->nodeValue;  
        $contents .= "<br />header: " . $headers[$file] . "</p>\n";
      }
    }
  }
  $contents .="</body></html>";
  return $contents;
}
/**
* Execute query and return node list
* @param string $file  The file name
* @param string $query The query to execute
* @return DOMNodeList
*/
function getNodes($file, $query){ 
  $d = new DOMDocument();
  $d->load($file);
  $xpath = new DOMXPath($d);
  $ns = $d->documentElement->namespaceURI;
  if($ns) {
    $xpath->registerNamespace("ns", $ns);
  } else {
    //remove "ns:"
    $query = str_replace("ns:", "", $query);
  }
  $nodes = $xpath->query($query);
  return $nodes;
}
?>