<?php
/**
* Format JSON uniformly. If it is already formatted,
* remove the formatting and repeat.
* Pass in a file name. Any <pre> tags must have the
* class attribute set to "json".
* @param string $argv[1] The name of the file
*/
$source = $argv[1]; 
$d = new DOMDocument();
$d->load($source);
$xpath = new DOMXPath($d);
//check for namespace
$ns = $d->documentElement->namespaceURI;
if($ns) {
  $xpath->registerNamespace("ns", $ns);
  //find all json pre tags
  $elements = $xpath->query("//ns:pre[@class='json']"); 
} else {
  $elements = $xpath->query("//pre[@class='json']");
}
for ($i = 0; $i < $elements->length; $i++) {
  $element = $elements->item($i);
  $content =  $element->textContent;
  //remove newlines, any existing formatting
  //this is not strictly necessary, pretty_print is
  //pretty versatile
  $content = trim(preg_replace('/\s+/', ' ', $content));
  $newcontent = "";
  $newcontent = pretty_print($content); 
  //assign data to text node
  if ($newcontent != "") {
    $newcontent = "\n" . $newcontent . "\n";
    $element->replaceChild(new DOMText($newcontent),
      $element->firstChild); 
  }
}
$d->save($source);
/**
* Format a JSON string for pretty printing. Adapted from
* http://stackoverflow.com/questions/6054033/pretty-printing-json-with-php
* @param string $json Unformatted JSON
* @return string Formatted JSON
*/
function pretty_print($json){ 
  $result = '';
  $level = 0;
  $prev_char = '';
  $tab = '  '; 
  $in_quotes = false;
  $ends_line_level = NULL;
  $json_length = strlen( $json );

  for( $i = 0; $i < $json_length; $i++ ) {
    $char = $json[$i];
    $new_line_level = NULL;
    $post = "";
    if( $ends_line_level !== NULL ) {
      $new_line_level = $ends_line_level;
      $ends_line_level = NULL;
    }
    if( $char === '"' && $prev_char != '\\' ) {
      $in_quotes = !$in_quotes;
    } else if( ! $in_quotes ) {
      switch( $char ) {
        case '}': case ']':
          $level--;
          $ends_line_level = NULL;
          $new_line_level = $level;
          break;

        case '{': case '[':
          $level++;
        case ',':
          $ends_line_level = $level;
          break;

        case ':':
          $post = " ";
          break;

        case " ": case "\t": case "\n": case "\r":
          $char = "";
          $ends_line_level = $new_line_level;
          $new_line_level = NULL;
          break;
      }
    }
    if( $new_line_level !== NULL ) {
      $result .= "\n".str_repeat( $tab, $new_line_level );
    }
    $result .= $char.$post;
    $prev_char = $char;
  }
  return $result;
}
?>