<?php
/**
* Turn the glossary HTML file into a series of
* separate topic files. Store these files in the
* gloss_topics directory.
* © 2017 Moneris Solutions Corporation, CC-BY-NC -SA 4.0
* @param string $argv[1] The glossary file name
*/
$source = $argv[1]; 
if(!file_exists("gloss_entries")){
  exec("mkdir gloss_entries"); 
}
$doc = new DOMDocument();
$doc->load($source);
$query = "//ns:dt"; 
$elements = getNodes($doc, $query);
//find all titles
$titles_array = Array(); 
foreach ($elements as $node){
  //add title to array
  $titles_array[] = trim($node->nodeValue);
}
$query = "//ns:dl/ns:dd"; 
$nodes = getNodes($doc, $query);
$index= 0;
foreach ($nodes as $node){
  $new_doc = new DOMDocument();
  $new_doc->formatOutput = true;
  $title = $titles_array[$index];
  //add a style link to the head below if required
  $new_glossary = "<?xml version=\"1.0\" encoding=\"utf-8\"?> 
  <html xmlns=\"http://www.w3.org/1999/xhtml\" 
    xmlns:MadCap=\"http://www.madcapsoftware.com/Schemas/MadCap.xsd\">
    <head>
    <title>" . $title . "</title>
    </head>   
  </html>
  ";
  $new_doc->loadXML($new_glossary);
  $ns = "http://www.w3.org/1999/xhtml";
  $body_node = $new_doc->createElementNS($ns,'body');
  $new_doc->documentElement->appendChild($body_node);
  //create <h1> from $titles[$index]
  $h = $new_doc->createElement('h1', $titles_array[$index]);
  $h->setAttribute("class", "no_number");
  $body_node->appendChild($h);
  
  //check for text only
  if ($node->childNodes->length == 1){ 
    $p = $new_doc->createElement("p", $node->nodeValue);
    $body_node->appendChild($p);
  } else {   
    foreach ($node->childNodes as $n) { 
      $import = $new_doc->importNode($n, true);
      $body_node->appendChild($import);  
    }
  }
  //clean file name  
  $pattern = "([\/\s\-_~,;:\[\]\(\).])";
  $value = preg_replace($pattern, "", $titles_array[$index]);
  $value = strtolower($value);
  $new_doc->save("gloss_entries/$value" . ".html"); 
  $index ++;
}
/**
* Execute query and return node list
* @param DOMDocument $doc   The DOMDocument
* @param string      $query The query to execute
* @return DOMNodeList
*/
function getNodes($doc, $query){ 
  $xpath = new DOMXPath($doc);
  $ns = $doc->documentElement->namespaceURI;
  if($ns) {
    $xpath->registerNamespace("ns", $ns);
  } else {
    //remove "ns:"
    $query = str_replace("ns:", "", $query);
  }
  $nodes = $xpath->query($query);
  return $nodes;
}
?>
