<?php
/**
* Replace glossary hrefs with glossaryTerms. This script
* converts any internal glossary hrefs:
* <a href="glossary.html#term">Term</a>
*      to:
* <MadCap:glossaryTerm
* glossTerm="NewGlossary.Term27">Term</MadCap:glossaryTerm>
*
* Note that glossary.html will be replaced by the name of the
* HTML glossary file ($argv[1]).
*
* @param string $argv[1] The HTML glossary file
* @param string $argv[2] The Flare glossary file (.flglo)
*/ 
$html_glossary = $argv[1];  
$flare_glossary = $argv[2]; 
//examine all files for glossary references
foreach (glob("./*.{xhtml,html,htm}", GLOB_BRACE) as $file){
  $changed = false;
  $d = new DOMDocument();
  $d->formatOutput = true;
  $d->load($file);
  $xpath = new DOMXPath($d);
  //get namespace
  $ns = $d->documentElement->namespaceURI;
  if($ns) {
    $xpath->registerNamespace("ns", $ns);
    //find all
    $elements = $xpath->query("//ns:a[@href]");
  } else {
    $elements = $xpath->query("//a[@href]");
  }
  if($elements->item(0)){
    foreach ($elements as $node) {
      $href = $node->getAttribute("href");
      //does it reference the glossary file?
      if (strpos($href, $html_glossary) !== false ) { 
        //clean up the text, remove CR, tab and 
        //only single space between words 
        $term = preg_replace('/\s+/', ' ', $node->nodeValue);        
        //look up term in the flglo file
        $attribute = getglossTermAttribute($term, $flare_glossary);
        //may fail
        if($attribute == ""){
          echo "Failed to find $term.\n";
        }else {
          $glossaryTerm = $d->createElement('MadCap:glossaryTerm', 
            $term);
          $glossaryTerm->setAttribute("glossTerm", $attribute);
          $parent = $node->parentNode;
          $parent->replaceChild($glossaryTerm, $node);
          $changed = true;
        }
      }
    }
    if ($changed){
      $d->save($file);
    }
  }
}
/**
* Find the glossaryTerm attribute in the glossary
* @param string $term           The term to look up
* @param string $flare_glossary The Flare glossary
* @return string The glossTerm attribute
*/
function getglossTermAttribute($term, $flare_glossary) { 
  $glossterm = "";
  $d = new DOMDocument();
  $d->load($flare_glossary);
  $xpath = new DOMXPath($d);
  $elements = $xpath->query("//Term");
  foreach ($elements as $node) {
    if($term == trim($node->nodeValue)){
      //need grandparent of Term
      $glossaryEntry = $node->parentNode->parentNode;
      $glossterm = $glossaryEntry->getAttribute("glossTerm");
      break;
    }
  }
  return $glossterm;
}
?>